@@ -1,7 +1,8 @@
+=encoding iso-8859-1
 
 =head1 NAME
 
-PDL::Func - useful functions
+PDL::Func - interpolation, integration, & gradient estimation (differentiation) of functions
 
 =head1 SYNOPSIS
 
@@ -480,8 +481,8 @@ sub _get_value {
 
 =for usage
 
- my $nset = $obj->set( x => $newx, $y => $newy );
- my $nset = $obj->set( { x => $newx, $y => $newy } );
+ my $nset = $obj->set( x => $newx, y => $newy );
+ my $nset = $obj->set( { x => $newx, y => $newy } );
 
 =for ref
 
@@ -933,11 +934,6 @@ current implementation, as it is not too sensible.
 
 Thanks to Robin Williams, Halldr Olafsson, and Vince McIntyre.
 
-=head1 THE FUTURE
-
-Robin is working on a new version, that improves on the current version
-a lot. No time scale though!
-
 =head1 AUTHOR
 
 Copyright (C) 2000,2001 Doug Burke (dburke@cfa.harvard.edu).
